@@ -1,4 +1,4 @@
-#!/usr/pkg/bin/python3.12
+#!/usr/pkg/bin/python3.13
 # coding=utf-8
 #
 # Copyright (C) 2011 Nikita Kitaev
@@ -156,9 +156,9 @@ class SynfigDocument(object):
 
         y = self.height - y
 
-        assert (
-            self.coor_svg2sif([x, y]) == vector
-        ), "sif to svg coordinate conversion error"
+        assert self.coor_svg2sif([x, y]) == vector, (
+            "sif to svg coordinate conversion error"
+        )
 
         return [x, y]
 
